@@ -6,7 +6,7 @@ use crate::new_less::file::path_resolve;
 fn test_arco_pro_1_less() {
   let filepath = path_resolve("assets/arco-pro/1.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .customer-tooltip-title {
   margin-bottom: 4px;
@@ -45,7 +45,7 @@ body[arco-theme='dark'] .customer-tooltip-item {
 fn test_arco_pro_2_less() {
   let filepath = path_resolve("assets/arco-pro/2.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .footer{
   display: flex;
@@ -66,7 +66,7 @@ fn test_arco_pro_2_less() {
 fn test_arco_pro_3_less() {
   let filepath = path_resolve("assets/arco-pro/3.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .message-box{
   width: 400px;
@@ -132,7 +132,7 @@ fn test_arco_pro_3_less() {
 fn test_arco_pro_4_less() {
   let filepath = path_resolve("assets/arco-pro/4.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .icon-button{
   font-size: 16px;
@@ -153,7 +153,7 @@ fn test_arco_pro_4_less() {
 fn test_arco_pro_5_less() {
   let filepath = path_resolve("assets/arco-pro/5.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .navbar {
   display: flex;
@@ -229,7 +229,7 @@ fn test_arco_pro_5_less() {
 fn test_arco_pro_6_less() {
   let filepath = path_resolve("assets/arco-pro/6.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .panel {
   background-color: var(--color-bg-2);
@@ -246,7 +246,7 @@ fn test_arco_pro_6_less() {
 fn test_arco_pro_7_less() {
   let filepath = path_resolve("assets/arco-pro/7.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .block {
   margin-bottom: 24px;
@@ -273,7 +273,7 @@ fn test_arco_pro_7_less() {
 fn test_arco_pro_8_less() {
   let filepath = path_resolve("assets/arco-pro/8.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .input {
   display: flex;
@@ -308,7 +308,7 @@ fn test_arco_pro_8_less() {
 fn test_arco_pro_9_less() {
   let filepath = path_resolve("assets/arco-pro/9.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .message-item {
   font-size: 12px;
@@ -363,7 +363,7 @@ fn test_arco_pro_9_less() {
 fn test_arco_pro_10_less() {
   let filepath = path_resolve("assets/arco-pro/10.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .layout {
   display: flex;
@@ -445,7 +445,7 @@ fn test_arco_pro_10_less() {
 fn test_arco_pro_11_less() {
   let filepath = path_resolve("assets/arco-pro/11.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .item {
   display: flex;
@@ -476,7 +476,7 @@ fn test_arco_pro_11_less() {
 fn test_arco_pro_12_less() {
   let filepath = path_resolve("assets/arco-pro/12.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .docs {
   display: grid;
@@ -502,7 +502,7 @@ fn test_arco_pro_12_less() {
 fn test_arco_pro_13_less() {
   let filepath = path_resolve("assets/arco-pro/13.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .banner {
   background-color: var(--color-bg-2);
@@ -531,7 +531,7 @@ fn test_arco_pro_13_less() {
 fn test_arco_pro_14_less() {
   let filepath = path_resolve("assets/arco-pro/14.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .container {
   padding: 20px;
@@ -602,7 +602,7 @@ fn test_arco_pro_14_less() {
 fn test_arco_pro_15_less() {
   let filepath = path_resolve("assets/arco-pro/15.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .symbol {
   font-size: 10px;
@@ -622,7 +622,7 @@ fn test_arco_pro_15_less() {
 fn test_arco_pro_16_less() {
   let filepath = path_resolve("assets/arco-pro/16.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .shortcuts {
   display: grid;
@@ -682,7 +682,7 @@ fn test_arco_pro_16_less() {
 fn test_arco_pro_17_less() {
   let filepath = path_resolve("assets/arco-pro/17.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .wrapper {
   position: relative;
@@ -705,7 +705,7 @@ fn test_arco_pro_17_less() {
 fn test_arco_pro_18_less() {
   let filepath = path_resolve("assets/arco-pro/18.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .wrapper {
   position: relative;
@@ -728,7 +728,7 @@ fn test_arco_pro_18_less() {
 fn test_arco_pro_19_less() {
   let filepath = path_resolve("assets/arco-pro/19.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .wrapper {
   position: relative;
@@ -751,7 +751,7 @@ fn test_arco_pro_19_less() {
 fn test_arco_pro_20_less() {
   let filepath = path_resolve("assets/arco-pro/20.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .container {
   overflow: hidden;
@@ -784,7 +784,7 @@ fn test_arco_pro_20_less() {
 fn test_arco_pro_21_less() {
   let filepath = path_resolve("assets/arco-pro/21.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .container :global(.arco-card-body) {
   padding: 20px;
@@ -828,7 +828,7 @@ fn test_arco_pro_21_less() {
 fn test_arco_pro_22_less() {
   let filepath = path_resolve("assets/arco-pro/22.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .container :global(.arco-list-content) {
   overflow-x: hidden;
@@ -959,7 +959,7 @@ fn test_arco_pro_22_less() {
 fn test_arco_pro_23_less() {
   let filepath = path_resolve("assets/arco-pro/23.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .toolbar {
   display: flex;
@@ -1012,7 +1012,7 @@ fn test_arco_pro_23_less() {
 fn test_arco_pro_24_less() {
   let filepath = path_resolve("assets/arco-pro/24.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .container {
   display: flex;
@@ -1124,7 +1124,7 @@ fn test_arco_pro_24_less() {
 fn test_arco_pro_25_less() {
   let filepath = path_resolve("assets/arco-pro/25.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .container :global(.arco-card) {
   margin-top: 16px;
@@ -1146,7 +1146,7 @@ fn test_arco_pro_25_less() {
 fn test_arco_pro_26_less() {
   let filepath = path_resolve("assets/arco-pro/26.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .wrapper {
   padding: 24px 150px;
@@ -1175,7 +1175,7 @@ fn test_arco_pro_26_less() {
 fn test_arco_pro_27_less() {
   let filepath = path_resolve("assets/arco-pro/27.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .wrapper {
   padding: 24px 150px;
@@ -1205,7 +1205,7 @@ fn test_arco_pro_27_less() {
 fn test_arco_pro_28_less() {
   let filepath = path_resolve("assets/arco-pro/28.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .project-wrapper {
   cursor: pointer;
@@ -1233,7 +1233,7 @@ fn test_arco_pro_28_less() {
 fn test_arco_pro_29_less() {
   let filepath = path_resolve("assets/arco-pro/29.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .header {
   height: 200px;
@@ -1296,7 +1296,7 @@ fn test_arco_pro_29_less() {
 fn test_arco_pro_30_less() {
   let filepath = path_resolve("assets/arco-pro/30.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .info-wrapper {
   display: flex;
@@ -1336,7 +1336,7 @@ fn test_arco_pro_30_less() {
 fn test_arco_pro_31_less() {
   let filepath = path_resolve("assets/arco-pro/31.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .wrapper {
   display: flex;
@@ -1406,7 +1406,7 @@ fn test_arco_pro_31_less() {
 fn test_arco_pro_32_less() {
   let filepath = path_resolve("assets/arco-pro/32.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .card {
   display: flex;
@@ -1478,7 +1478,7 @@ body[arco-theme='dark'] .card-interval {
 fn test_arco_pro_33_less() {
   let filepath = path_resolve("assets/arco-pro/33.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .card .statistic {
   display: flex;
@@ -1525,7 +1525,7 @@ fn test_arco_pro_33_less() {
 fn test_arco_pro_34_less() {
   let filepath = path_resolve("assets/arco-pro/34.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .card :global(.arco-spin) {
   width: 100%;
@@ -1567,7 +1567,7 @@ fn test_arco_pro_34_less() {
 fn test_arco_pro_35_less() {
   let filepath = path_resolve("assets/arco-pro/35.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .code-block {
   color: var(--color-text-2);
@@ -1592,7 +1592,7 @@ fn test_arco_pro_35_less() {
 fn test_arco_pro_36_less() {
   let filepath = path_resolve("assets/arco-pro/36.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .header {
   background: var(--color-bg-2);
@@ -1609,7 +1609,7 @@ fn test_arco_pro_36_less() {
 fn test_arco_pro_37_less() {
   let filepath = path_resolve("assets/arco-pro/37.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 #nprogress {
   pointer-events: none;
@@ -1711,7 +1711,7 @@ body[arco-theme='dark'] .chart-wrapper .bizcharts-tooltip {
 fn test_arco_pro_38_less() {
   let filepath = path_resolve("assets/arco-pro/38.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 .layout {
   width: 100%;
@@ -1839,7 +1839,7 @@ fn test_arco_pro_38_less() {
 fn test_arco_pro_39_less() {
   let filepath = path_resolve("assets/arco-pro/39.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#""#;
   assert_eq!(
     css.simple_compare(),
@@ -1851,7 +1851,7 @@ fn test_arco_pro_39_less() {
 fn test_arco_pro_42_less() {
   let filepath = path_resolve("assets/arco-pro/42.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#""#;
   assert_eq!(
     css.simple_compare(),
@@ -1863,7 +1863,7 @@ fn test_arco_pro_42_less() {
 fn test_arco_pro_43_less() {
   let filepath = path_resolve("assets/arco-pro/43.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#""#;
   assert_eq!(
     css.simple_compare(),
@@ -1875,7 +1875,7 @@ fn test_arco_pro_43_less() {
 fn test_arco_pro_44_less() {
   let filepath = path_resolve("assets/arco-pro/44.less");
   let app = Application::default();
-  let css = app.render(filepath).unwrap();
+  let css = app.render(filepath.as_str()).unwrap();
   let target_code = r#"
 #nprogress {
   pointer-events: none;
